@@ -7,7 +7,7 @@ from typing import Optional, Tuple, Union
 
 import cv2
 import numpy as np
-from moviepy.editor import VideoFileClip
+from moviepy.editor import VideoFileClip, concatenate, vfx
 from rich import print
 from rich.console import Console
 from rich.progress import Progress
@@ -106,9 +106,7 @@ class BaseVideoExtractor:
             self.fps = round(video_capture.get(cv2.CAP_PROP_FPS), 2)
 
         self.video_length_seconds = round(self.frame_count / self.fps, 2)
-        self.video_length = str(
-            datetime.timedelta(seconds=self.video_length_seconds)
-        ).split(".")[0]
+        self.video_length = utils.seconds_to_timestamp(self.video_length_seconds)
 
         self.video_dimensions = (
             int(video_capture.get(cv2.CAP_PROP_FRAME_WIDTH)),
@@ -242,8 +240,8 @@ class BaseVideoExtractor:
                 self.target_dimensions = self.video_dimensions
 
     def __str__(self) -> str:
-        start_time_display = f"{utils.seconds_to_timestamp(int(self.start_second))} | {self.start_second} seconds"
-        stop_time_display = f"{utils.seconds_to_timestamp(int(self.stop_second))} | {self.stop_second} seconds"
+        start_time_display = f"{utils.seconds_to_timestamp(self.start_second)} | {self.start_second} seconds"
+        stop_time_display = f"{utils.seconds_to_timestamp(self.stop_second)} | {self.stop_second} seconds"
         if self.emoji:
             start_time_display = f"{C.EMOJI_MAP['start']} {start_time_display}"
             stop_time_display = f"{C.EMOJI_MAP['stop']} {stop_time_display}"
@@ -386,6 +384,7 @@ class VideoToImages(BaseVideoExtractor):
 @dataclass
 class VideoToGIF(BaseVideoExtractor):
     speed: float = 1.0
+    bounce: bool = False
 
     def __post_init__(self) -> None:
         super().__post_init__()
@@ -401,6 +400,9 @@ class VideoToGIF(BaseVideoExtractor):
         if self.rotate != 0:
             subclip = subclip.rotate(self.rotate)
 
+        if self.bounce:
+            subclip = concatenate([subclip, subclip.fx(vfx.time_mirror)])
+
         return subclip
 
     def create_gif(self) -> None:
@@ -453,6 +455,7 @@ class VideoToGIF(BaseVideoExtractor):
               resize:       {resize_display}
               rotate:       {rotate_display}
               speed:        {speed_display}
+              bounce:       {self.bounce}
               dimensions:   {self.target_dimensions}
               """
         )
